# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: imagery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import aoi_pb2 as aoi__pb2
try:
  common__models__pb2 = aoi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.aoi_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rimagery.proto\x12\x0foi.papi.imagery\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\x1a\taoi.proto\"\xd8\x04\n\x14ImagerySearchRequest\x12(\n\x06\x61oi_id\x18\x01 \x01(\x0b\x32\x16.oi.papi.AOIIdentifierH\x00\x12\x16\n\x0cgeometry_wkb\x18\x02 \x01(\x0cH\x00\x12\x10\n\x06toi_id\x18\x03 \x01(\tH\x01\x12\x45\n\ntime_range\x18\x04 \x01(\x0b\x32/.oi.papi.imagery.ImagerySearchRequest.TimeRangeH\x01\x12\x16\n\x0e\x64\x61ta_source_id\x18\x05 \x01(\t\x12\x19\n\x11product_spec_name\x18\x06 \x01(\t\x12\x34\n\x13\x64\x61ta_source_filters\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\npagination\x18\t \x01(\x0b\x32\x13.oi.papi.Pagination\x12M\n\x0fsampling_config\x18\n \x01(\x0b\x32\x34.oi.papi.imagery.ImagerySearchRequest.SamplingConfig\x1a\x42\n\x0eSamplingConfig\x12\x17\n\x0f\x66requency_hours\x18\x01 \x01(\r\x12\x17\n\x0ftolerance_hours\x18\x02 \x01(\r\x1aj\n\tTimeRange\x12-\n\tstart_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nfinish_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\n\x04\x61reaB\x06\n\x04timeJ\x04\x08\x08\x10\t\"\xd5\x02\n\x15ImagerySearchResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12K\n\x07results\x18\x02 \x03(\x0b\x32:.oi.papi.imagery.ImagerySearchResponse.ImagerySearchResult\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\x1a\xb0\x01\n\x13ImagerySearchResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x19\n\x11provider_scene_id\x18\x02 \x01(\t\x12\x16\n\x0eimage_geom_wkb\x18\x03 \x01(\x0c\x12/\n\x0b\x61\x63quired_ts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct2e\n\nImageryApi\x12W\n\x06search\x12%.oi.papi.imagery.ImagerySearchRequest\x1a&.oi.papi.imagery.ImagerySearchResponseP\x02P\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'imagery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_IMAGERYSEARCHREQUEST']._serialized_start=130
  _globals['_IMAGERYSEARCHREQUEST']._serialized_end=730
  _globals['_IMAGERYSEARCHREQUEST_SAMPLINGCONFIG']._serialized_start=534
  _globals['_IMAGERYSEARCHREQUEST_SAMPLINGCONFIG']._serialized_end=600
  _globals['_IMAGERYSEARCHREQUEST_TIMERANGE']._serialized_start=602
  _globals['_IMAGERYSEARCHREQUEST_TIMERANGE']._serialized_end=708
  _globals['_IMAGERYSEARCHRESPONSE']._serialized_start=733
  _globals['_IMAGERYSEARCHRESPONSE']._serialized_end=1074
  _globals['_IMAGERYSEARCHRESPONSE_IMAGERYSEARCHRESULT']._serialized_start=898
  _globals['_IMAGERYSEARCHRESPONSE_IMAGERYSEARCHRESULT']._serialized_end=1074
  _globals['_IMAGERYAPI']._serialized_start=1076
  _globals['_IMAGERYAPI']._serialized_end=1177
# @@protoc_insertion_point(module_scope)
