# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aoi_version.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import aoi_pb2 as aoi__pb2
try:
  common__models__pb2 = aoi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.aoi_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61oi_version.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\taoi.proto\"s\n\x14\x41OIVersionGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\r\x12%\n\naoi_fields\x18\x02 \x03(\x0e\x32\x11.oi.papi.AOIField\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x80\x01\n\x15\x41OIVersionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12)\n\x0c\x61oi_versions\x18\x03 \x03(\x0b\x32\x13.oi.papi.AOIVersion\"\\\n\x17\x41OIVersionCreateRequest\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x31\n\x16\x61oi_modification_input\x18\x02 \x01(\x0b\x32\x11.oi.papi.AOIInput\"\x82\x01\n\x18\x41OIVersionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12(\n\x0b\x61oi_version\x18\x03 \x01(\x0b\x32\x13.oi.papi.AOIVersion\"\xa7\x02\n\x15\x41OIVersionListRequest\x12\x10\n\x08geom_wkt\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x13\n\x0bsearch_text\x18\x04 \x01(\t\x12\x32\n\x0emin_created_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12%\n\naoi_fields\x18\x07 \x03(\x0e\x32\x11.oi.papi.AOIField\x12\'\n\npagination\x18\x08 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x0f\n\x07verbose\x18\t \x01(\x08\"\x81\x01\n\x16\x41OIVersionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12)\n\x0c\x61oi_versions\x18\x03 \x03(\x0b\x32\x13.oi.papi.AOIVersion*\xea\x01\n\x08\x41OIField\x12\x15\n\x11UNKNOWN_AOI_FIELD\x10\x00\x12\n\n\x06\x41OI_ID\x10\x01\x12\x0c\n\x08GEOM_WKT\x10\x02\x12\x07\n\x03LAT\x10\x03\x12\x08\n\x04LONG\x10\x04\x12\x08\n\x04NAME\x10\x05\x12\x0c\n\x08\x41REA_KM2\x10\x06\x12\x0c\n\x08\x43\x41TEGORY\x10\x07\x12\x08\n\x04TYPE\x10\x08\x12\n\n\x06SOURCE\x10\t\x12\x0b\n\x07\x43OUNTRY\x10\n\x12\t\n\x05STATE\x10\x0b\x12\x08\n\x04TAGS\x10\x0c\x12\x0e\n\nATTRIBUTES\x10\r\x12\x0c\n\x08TIMEZONE\x10\x0e\x12\x0e\n\nCREATED_ON\x10\x0f\x12\x0e\n\nCREATED_BY\x10\x10\x32\xed\x01\n\rAOIVersionApi\x12M\n\x06\x63reate\x12 .oi.papi.AOIVersionCreateRequest\x1a!.oi.papi.AOIVersionCreateResponse\x12\x44\n\x03get\x12\x1d.oi.papi.AOIVersionGetRequest\x1a\x1e.oi.papi.AOIVersionGetResponse\x12G\n\x04list\x12\x1e.oi.papi.AOIVersionListRequest\x1a\x1f.oi.papi.AOIVersionListResponseP\x00P\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_version_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AOIFIELD']._serialized_start=1001
  _globals['_AOIFIELD']._serialized_end=1235
  _globals['_AOIVERSIONGETREQUEST']._serialized_start=95
  _globals['_AOIVERSIONGETREQUEST']._serialized_end=210
  _globals['_AOIVERSIONGETRESPONSE']._serialized_start=213
  _globals['_AOIVERSIONGETRESPONSE']._serialized_end=341
  _globals['_AOIVERSIONCREATEREQUEST']._serialized_start=343
  _globals['_AOIVERSIONCREATEREQUEST']._serialized_end=435
  _globals['_AOIVERSIONCREATERESPONSE']._serialized_start=438
  _globals['_AOIVERSIONCREATERESPONSE']._serialized_end=568
  _globals['_AOIVERSIONLISTREQUEST']._serialized_start=571
  _globals['_AOIVERSIONLISTREQUEST']._serialized_end=866
  _globals['_AOIVERSIONLISTRESPONSE']._serialized_start=869
  _globals['_AOIVERSIONLISTRESPONSE']._serialized_end=998
  _globals['_AOIVERSIONAPI']._serialized_start=1238
  _globals['_AOIVERSIONAPI']._serialized_end=1475
# @@protoc_insertion_point(module_scope)
