# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"7\n\rLoginResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tjwt_token\x18\x02 \x01(\t\"G\n\x19UserChangePasswordRequest\x12\x14\n\x0cold_password\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"1\n\x1aUserChangePasswordResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"/\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"L\n\x11UserCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x1a\n\x12user_collection_id\x18\x03 \x01(\t\"F\n\x12UserCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.oi.papi.User\"\x1d\n\x0eUserGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"D\n\x0fUserGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User\" \n\x0fUserListRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"E\n\x10UserListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User2\xd7\x02\n\x07UserApi\x12\x36\n\x05login\x12\x15.oi.papi.LoginRequest\x1a\x16.oi.papi.LoginResponse\x12Z\n\x0f\x63hange_password\x12\".oi.papi.UserChangePasswordRequest\x1a#.oi.papi.UserChangePasswordResponse\x12\x41\n\x06\x63reate\x12\x1a.oi.papi.UserCreateRequest\x1a\x1b.oi.papi.UserCreateResponse\x12\x38\n\x03get\x12\x17.oi.papi.UserGetRequest\x1a\x18.oi.papi.UserGetResponse\x12;\n\x04list\x12\x18.oi.papi.UserListRequest\x1a\x19.oi.papi.UserListResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOGINREQUEST']._serialized_start=44
  _globals['_LOGINREQUEST']._serialized_end=91
  _globals['_LOGINRESPONSE']._serialized_start=93
  _globals['_LOGINRESPONSE']._serialized_end=148
  _globals['_USERCHANGEPASSWORDREQUEST']._serialized_start=150
  _globals['_USERCHANGEPASSWORDREQUEST']._serialized_end=221
  _globals['_USERCHANGEPASSWORDRESPONSE']._serialized_start=223
  _globals['_USERCHANGEPASSWORDRESPONSE']._serialized_end=272
  _globals['_USER']._serialized_start=274
  _globals['_USER']._serialized_end=321
  _globals['_USERCREATEREQUEST']._serialized_start=323
  _globals['_USERCREATEREQUEST']._serialized_end=399
  _globals['_USERCREATERESPONSE']._serialized_start=401
  _globals['_USERCREATERESPONSE']._serialized_end=471
  _globals['_USERGETREQUEST']._serialized_start=473
  _globals['_USERGETREQUEST']._serialized_end=502
  _globals['_USERGETRESPONSE']._serialized_start=504
  _globals['_USERGETRESPONSE']._serialized_end=572
  _globals['_USERLISTREQUEST']._serialized_start=574
  _globals['_USERLISTREQUEST']._serialized_end=606
  _globals['_USERLISTRESPONSE']._serialized_start=608
  _globals['_USERLISTRESPONSE']._serialized_end=677
  _globals['_USERAPI']._serialized_start=680
  _globals['_USERAPI']._serialized_end=1023
# @@protoc_insertion_point(module_scope)
