# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aoi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\taoi.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"\x8c\x01\n\x0e\x41OITransaction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"7\n\rAOIIdentifier\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x16\n\x0e\x61oi_version_id\x18\x02 \x01(\r\"\xa5\x02\n\tAOIObject\x12.\n\x0e\x61oi_identifier\x18\x01 \x01(\x0b\x32\x16.oi.papi.AOIIdentifier\x12\x10\n\x08geom_wkt\x18\x02 \x01(\t\x12\x0b\n\x03lat\x18\x03 \x01(\x02\x12\x0c\n\x04long\x18\x04 \x01(\x02\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x61rea_km2\x18\x06 \x01(\x01\x12\x10\n\x08\x63\x61tegory\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x12\x0e\n\x06source\x18\t \x01(\t\x12\x0f\n\x07\x63ountry\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\x12\x0c\n\x04tags\x18\x0c \x03(\t\x12+\n\nattributes\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08timezone\x18\x0e \x01(\t\"\xdf\x02\n\nAOIVersion\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06\x61oi_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63reator\x18\x04 \x01(\t\x12\x10\n\x08\x61oi_name\x18\x05 \x01(\t\x12\x10\n\x08geom_wkt\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\x02\x12\x0c\n\x04long\x18\x08 \x01(\x02\x12\x10\n\x08\x61rea_km2\x18\t \x01(\x01\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x0e\n\x06source\x18\x0c \x01(\t\x12\x0f\n\x07\x63ountry\x18\r \x01(\t\x12\r\n\x05state\x18\x0e \x01(\t\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12+\n\nattributes\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08timezone\x18\x11 \x01(\t\"\x95\x01\n\x08\x41OIInput\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x10\n\x08geom_wkt\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12+\n\nattributes\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\"T\n\x10\x41OICreateRequest\x12%\n\naoi_inputs\x18\x01 \x03(\x0b\x32\x11.oi.papi.AOIInput\x12\x19\n\x11\x61oi_collection_id\x18\x02 \x01(\t\"\x94\x01\n\x11\x41OICreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12/\n\x0f\x61oi_identifiers\x18\x03 \x03(\x0b\x32\x16.oi.papi.AOIIdentifier\x12\x10\n\x08\x61rea_km2\x18\x04 \x03(\x01\"<\n\x10\x41OIUploadRequest\x12\x19\n\x11\x61oi_collection_id\x18\x01 \x01(\t\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\"Z\n\x11\x41OIUploadResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x30\n\x0f\x61oi_transaction\x18\x02 \x01(\x0b\x32\x17.oi.papi.AOITransaction\"V\n\rAOIGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x0f\n\x07verbose\x18\x02 \x01(\x08\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"y\n\x0e\x41OIGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12)\n\x0c\x61oi_versions\x18\x03 \x03(\x0b\x32\x13.oi.papi.AOIVersion\"U\n\x10\x41OIUpdateRequest\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x31\n\x16\x61oi_modification_input\x18\x02 \x01(\x0b\x32\x11.oi.papi.AOIInput\"(\n\x11\x41OIUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\x85\x02\n\x06\x41OIApi\x12?\n\x06\x63reate\x12\x19.oi.papi.AOICreateRequest\x1a\x1a.oi.papi.AOICreateResponse\x12\x36\n\x03get\x12\x16.oi.papi.AOIGetRequest\x1a\x17.oi.papi.AOIGetResponse\x12\x41\n\x06upload\x12\x19.oi.papi.AOIUploadRequest\x1a\x1a.oi.papi.AOIUploadResponse(\x01\x12?\n\x06update\x12\x19.oi.papi.AOIUpdateRequest\x1a\x1a.oi.papi.AOIUpdateResponseP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AOITRANSACTION']._serialized_start=107
  _globals['_AOITRANSACTION']._serialized_end=247
  _globals['_AOIIDENTIFIER']._serialized_start=249
  _globals['_AOIIDENTIFIER']._serialized_end=304
  _globals['_AOIOBJECT']._serialized_start=307
  _globals['_AOIOBJECT']._serialized_end=600
  _globals['_AOIVERSION']._serialized_start=603
  _globals['_AOIVERSION']._serialized_end=954
  _globals['_AOIINPUT']._serialized_start=957
  _globals['_AOIINPUT']._serialized_end=1106
  _globals['_AOICREATEREQUEST']._serialized_start=1108
  _globals['_AOICREATEREQUEST']._serialized_end=1192
  _globals['_AOICREATERESPONSE']._serialized_start=1195
  _globals['_AOICREATERESPONSE']._serialized_end=1343
  _globals['_AOIUPLOADREQUEST']._serialized_start=1345
  _globals['_AOIUPLOADREQUEST']._serialized_end=1405
  _globals['_AOIUPLOADRESPONSE']._serialized_start=1407
  _globals['_AOIUPLOADRESPONSE']._serialized_end=1497
  _globals['_AOIGETREQUEST']._serialized_start=1499
  _globals['_AOIGETREQUEST']._serialized_end=1585
  _globals['_AOIGETRESPONSE']._serialized_start=1587
  _globals['_AOIGETRESPONSE']._serialized_end=1708
  _globals['_AOIUPDATEREQUEST']._serialized_start=1710
  _globals['_AOIUPDATEREQUEST']._serialized_end=1795
  _globals['_AOIUPDATERESPONSE']._serialized_start=1797
  _globals['_AOIUPDATERESPONSE']._serialized_end=1837
  _globals['_AOIAPI']._serialized_start=1840
  _globals['_AOIAPI']._serialized_end=2101
# @@protoc_insertion_point(module_scope)
