# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: result.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import toi_pb2 as toi__pb2
try:
  common__models__pb2 = toi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = toi__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.toi_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cresult.proto\x12\x07oi.papi\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\ttoi.proto\"\xae\x05\n\x06Result\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12source_aoi_version\x18\x03 \x01(\r\x12\x18\n\x10\x64\x65st_aoi_version\x18\x04 \x01(\r\x12\x19\n\x11\x61lgo_config_class\x18\x05 \x01(\t\x12\x1c\n\x14\x61lgo_config_subclass\x18\x06 \x01(\t\x12\x31\n\x0cobservations\x18\x07 \x03(\x0b\x32\x1b.oi.papi.Result.Observation\x12\x11\n\tdata_type\x18\x08 \x01(\t\x1a\xb2\x03\n\x0bObservation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61ta_view_id\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08start_ts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x05value\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x06status\x18\x06 \x01(\x0e\x32\".oi.papi.Result.Observation.Status\x12=\n\x0cmeasurements\x18\x07 \x03(\x0b\x32\'.oi.papi.Result.Observation.Measurement\x1aO\n\x0bMeasurement\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0c\n\x04geom\x18\x03 \x01(\t\"7\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0c\n\x08\x43OMPLETE\x10\x01\x12\x0b\n\x07PARTIAL\x10\x02\"\xb9\x03\n\x10ResultGetRequest\x12 \n\x18\x61lgorithm_computation_id\x18\x01 \x01(\t\x12\x1a\n\x12source_aoi_version\x18\x02 \x01(\r\x12\x18\n\x10\x64\x65st_aoi_version\x18\x03 \x01(\r\x12\x19\n\x11\x61lgo_config_class\x18\x04 \x01(\t\x12\x1c\n\x14\x61lgo_config_subclass\x18\x05 \x01(\t\x12.\n\ncreated_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14observation_start_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08geom_wkt\x18\x08 \x01(\t\x12>\n\x12observation_status\x18\t \x01(\x0e\x32\".oi.papi.Result.Observation.Status\x12\x1c\n\x14include_measurements\x18\n \x01(\x08\x12\x11\n\tdata_type\x18\x0b \x01(\t\x12\'\n\npagination\x18\x0c \x01(\x0b\x32\x13.oi.papi.Pagination\"s\n\x11ResultGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12 \n\x07results\x18\x03 \x03(\x0b\x32\x0f.oi.papi.Result\"\xeb\x02\n\x13ResultExportRequest\x12 \n\x18\x61lgorithm_computation_id\x18\x01 \x01(\t\x12<\n\x0b\x65xport_type\x18\x02 \x01(\x0e\x32\'.oi.papi.ResultExportRequest.ExportType\x12\x38\n\tfile_type\x18\x03 \x01(\x0e\x32%.oi.papi.ResultExportRequest.FileType\x12\x1a\n\x12source_aoi_version\x18\x04 \x01(\r\"U\n\nExportType\x12\x17\n\x13UNKNOWN_EXPORT_TYPE\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x0c\n\x08\x44\x45TAILED\x10\x02\x12\x12\n\x0eSINGLE_OBJECTS\x10\x03\"G\n\x08\x46ileType\x12\x15\n\x11UNKNOWN_FILE_TYPE\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\x0b\n\x07GEOJSON\x10\x02\x12\x0e\n\nGEOPACKAGE\x10\x03\"c\n\x14ResultExportResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\x12 \n\x18\x61lgorithm_computation_id\x18\x03 \x01(\t2\xc3\x01\n\tResultApi\x12T\n\x03get\x12\x19.oi.papi.ResultGetRequest\x1a\x1a.oi.papi.ResultGetResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/result/get:\x01*\x12`\n\x06\x65xport\x12\x1c.oi.papi.ResultExportRequest\x1a\x1d.oi.papi.ResultExportResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/result/export:\x01*P\x03P\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'result_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESULTAPI.methods_by_name['get']._options = None
  _RESULTAPI.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\020\"\013/result/get:\001*'
  _RESULTAPI.methods_by_name['export']._options = None
  _RESULTAPI.methods_by_name['export']._serialized_options = b'\202\323\344\223\002\023\"\016/result/export:\001*'
  _globals['_RESULT']._serialized_start=151
  _globals['_RESULT']._serialized_end=837
  _globals['_RESULT_OBSERVATION']._serialized_start=403
  _globals['_RESULT_OBSERVATION']._serialized_end=837
  _globals['_RESULT_OBSERVATION_MEASUREMENT']._serialized_start=701
  _globals['_RESULT_OBSERVATION_MEASUREMENT']._serialized_end=780
  _globals['_RESULT_OBSERVATION_STATUS']._serialized_start=782
  _globals['_RESULT_OBSERVATION_STATUS']._serialized_end=837
  _globals['_RESULTGETREQUEST']._serialized_start=840
  _globals['_RESULTGETREQUEST']._serialized_end=1281
  _globals['_RESULTGETRESPONSE']._serialized_start=1283
  _globals['_RESULTGETRESPONSE']._serialized_end=1398
  _globals['_RESULTEXPORTREQUEST']._serialized_start=1401
  _globals['_RESULTEXPORTREQUEST']._serialized_end=1764
  _globals['_RESULTEXPORTREQUEST_EXPORTTYPE']._serialized_start=1606
  _globals['_RESULTEXPORTREQUEST_EXPORTTYPE']._serialized_end=1691
  _globals['_RESULTEXPORTREQUEST_FILETYPE']._serialized_start=1693
  _globals['_RESULTEXPORTREQUEST_FILETYPE']._serialized_end=1764
  _globals['_RESULTEXPORTRESPONSE']._serialized_start=1766
  _globals['_RESULTEXPORTRESPONSE']._serialized_end=1865
  _globals['_RESULTAPI']._serialized_start=1868
  _globals['_RESULTAPI']._serialized_end=2063
# @@protoc_insertion_point(module_scope)
