# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12notification.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"j\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08topic_id\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\t\x12(\n\x07\x66ilters\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"I\n\x19SubscriptionCreateRequest\x12,\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x15.oi.papi.Subscription\"K\n\x1aSubscriptionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x18\n\x10subscription_ids\x18\x02 \x03(\t\"(\n\x05Topic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\'\n\x10TopicListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"H\n\x11TopicListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1e\n\x06topics\x18\x02 \x03(\x0b\x32\x0e.oi.papi.Topic\"#\n\x07\x43hannel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\")\n\x12\x43hannelListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"N\n\x13\x43hannelListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\"\n\x08\x63hannels\x18\x02 \x03(\x0b\x32\x10.oi.papi.Channel\"(\n\x19SubscriptionDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"1\n\x1aSubscriptionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"B\n\x17SubscriptionListRequest\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x86\x01\n\x18SubscriptionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\rsubscriptions\x18\x02 \x03(\x0b\x32\x15.oi.papi.Subscription\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"t\n\x17NotificationSendRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12(\n\x07\x66ilters\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"/\n\x18NotificationSendResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\x95\x04\n\x0fNotificationApi\x12^\n\x13\x63reate_subscription\x12\".oi.papi.SubscriptionCreateRequest\x1a#.oi.papi.SubscriptionCreateResponse\x12\x43\n\nlist_topic\x12\x19.oi.papi.TopicListRequest\x1a\x1a.oi.papi.TopicListResponse\x12I\n\x0clist_channel\x12\x1b.oi.papi.ChannelListRequest\x1a\x1c.oi.papi.ChannelListResponse\x12^\n\x13\x64\x65lete_subscription\x12\".oi.papi.SubscriptionDeleteRequest\x1a#.oi.papi.SubscriptionDeleteResponse\x12X\n\x11list_subscription\x12 .oi.papi.SubscriptionListRequest\x1a!.oi.papi.SubscriptionListResponse\x12X\n\x11send_notification\x12 .oi.papi.NotificationSendRequest\x1a!.oi.papi.NotificationSendResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SUBSCRIPTION']._serialized_start=82
  _globals['_SUBSCRIPTION']._serialized_end=188
  _globals['_SUBSCRIPTIONCREATEREQUEST']._serialized_start=190
  _globals['_SUBSCRIPTIONCREATEREQUEST']._serialized_end=263
  _globals['_SUBSCRIPTIONCREATERESPONSE']._serialized_start=265
  _globals['_SUBSCRIPTIONCREATERESPONSE']._serialized_end=340
  _globals['_TOPIC']._serialized_start=342
  _globals['_TOPIC']._serialized_end=382
  _globals['_TOPICLISTREQUEST']._serialized_start=384
  _globals['_TOPICLISTREQUEST']._serialized_end=423
  _globals['_TOPICLISTRESPONSE']._serialized_start=425
  _globals['_TOPICLISTRESPONSE']._serialized_end=497
  _globals['_CHANNEL']._serialized_start=499
  _globals['_CHANNEL']._serialized_end=534
  _globals['_CHANNELLISTREQUEST']._serialized_start=536
  _globals['_CHANNELLISTREQUEST']._serialized_end=577
  _globals['_CHANNELLISTRESPONSE']._serialized_start=579
  _globals['_CHANNELLISTRESPONSE']._serialized_end=657
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_start=659
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_end=699
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_start=701
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_end=750
  _globals['_SUBSCRIPTIONLISTREQUEST']._serialized_start=752
  _globals['_SUBSCRIPTIONLISTREQUEST']._serialized_end=818
  _globals['_SUBSCRIPTIONLISTRESPONSE']._serialized_start=821
  _globals['_SUBSCRIPTIONLISTRESPONSE']._serialized_end=955
  _globals['_NOTIFICATIONSENDREQUEST']._serialized_start=957
  _globals['_NOTIFICATIONSENDREQUEST']._serialized_end=1073
  _globals['_NOTIFICATIONSENDRESPONSE']._serialized_start=1075
  _globals['_NOTIFICATIONSENDRESPONSE']._serialized_end=1122
  _globals['_NOTIFICATIONAPI']._serialized_start=1125
  _globals['_NOTIFICATIONAPI']._serialized_end=1658
# @@protoc_insertion_point(module_scope)
